# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'AUTO', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'SCORE', 'ZSCORE', 'GZSCORE', 'L1', 'L2', 'LOG', 'LOG1P', 'OT',
           'MMD', 'PSEUDO', 'PSEUDOTIME', 'DPT_PSEUDOTIME', 'PCS', 'COMP', 'LOAD', 'PROJ', 'COMPONENTS', 'LOADINGS',
           'PROJECTION', 'PROJECTIONS', 'SVD', 'LANDMARK', 'N_SVD', 'N_LANDMARK', 'SEED', 'RANDOM_STATE']

# %% ../nbs/31_mthd.ipynb 4
from nchr import U1
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'

AUTO = 'auto'

UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

SCORE = 'score'
ZSCORE = f'z{SCORE}'
GZSCORE = f'g{ZSCORE}'


L1 = 'l1'
L2 = 'l2'
LOG = 'log'
LOG1P = f'{LOG}1p'

OT = 'ot'
MMD = 'mmd'

# %% ../nbs/31_mthd.ipynb 7
PSEUDO = 'pseudo'
PSEUDOTIME = f'{PSEUDO}{TIME}'
DPT_PSEUDOTIME = f'{DPT}{U1}{PSEUDOTIME}'

# %% ../nbs/31_mthd.ipynb 8
PCS = 'pcs'

COMP = 'comp'
LOAD = 'load'
PROJ = 'proj'

COMPONENTS = f'{COMP}onents'
LOADINGS = f'{LOAD}ings'

PROJECTION = f'{PROJ}ection'
PROJECTIONS = f'{PROJECTION}s'

# %% ../nbs/31_mthd.ipynb 9
SVD = 'svd'
LANDMARK = 'landmark'

N_SVD = f'n_{SVD}'
N_LANDMARK = f'n_{LANDMARK}'

# %% ../nbs/31_mthd.ipynb 10
SEED = 'seed'
RANDOM_STATE = 'random_state'
